/*
    See the JupyterLab Developer Guide for useful CSS Patterns:

    https://jupyterlab.readthedocs.io/en/stable/developer/css.html
*/
.j-project-empty-container {
  display: flex;
  flex-direction: column;
  align-items: center;
  width: 100%;
}

.j-project-empty-text {
  margin: 30px;
}

.j-project-create-button {
  border: 1px solid var(--jp-border-color1);
  cursor: pointer;
}

.j-project-create-dialog-button {
  background: white;
}

.j-chapter {
  display: flex;
  flex-direction: row;
  align-items: center;
  font-weight: normal;
  line-height: 32px;
  user-select: none;
  justify-content: space-between;
}

.j-chapter:hover {
  background-color: var(--jp-layout-color2);
}

.j-chapter.current {
  background-color: var(--jp-layout-color2);
}

.flex-center {
  display: flex;
  justify-content: center;
  align-items: center;
  flex-direction: row;
}

.jp-ToolbarButton {
  cursor: pointer;
}

.jp-project-node-icon {
  width: 30px;
  height: 30px;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
}

.rotate-90 {
  rotate: 270deg;
}

.jp-project-node-mini-icon {
  width: 8px;
  height: 8px;
  margin-left: 10px;
  margin-right: 15px;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
}

.jp-project-node-icon:hover {
  background-color: var(--jp-layout-color3);
  color: var(--jp-ui-inverse-font-color1);
}

.jp-filelist-widget {
  width: 700px;
  height: 100%;
  min-height: 200px;
  display: flex;
  flex-direction: column;
  overflow: hidden;
  border: 1px solid var(--jp-border-color2);
}

.jp-filelist-widget-breadcrumbs {
  width: 700px;
  font-size: 13px;
  user-select: none;
  margin: 5px;
}

.jp-filelist-widget-list-container {
  width: 700px;
  flex: 1;
  overflow-y: auto;
  border: 1px solid var(--jp-border-color2);
}
